#
# spec file for package lightdm
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2011 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
%define build_qt4 0
%else
%define build_qt4 1
%endif

%define ver_master      1.24
%define gobject_libname lightdm-gobject-1
%define gobject_lib     lib%{gobject_libname}-0
%define qt4_libname     lightdm-qt-3
%define qt4_lib         lib%{qt4_libname}-0
%define qt5_libname     lightdm-qt5-3
%define qt5_lib         lib%{qt5_libname}-0
%define qt6_libname     lightdm-qt6-3
%define qt6_lib         lib%{qt6_libname}-0
%define typelibname     typelib-1_0-LightDM-1
%define rundir          /run
Name:           lightdm
Version:        1.32.0
Release:        6.1
Summary:        Lightweight, Cross-desktop Display Manager
License:        GPL-3.0-or-later
Group:          System/X11/Displaymanagers
URL:            https://freedesktop.org/wiki/Software/LightDM
Source:         https://github.com/CanonicalLtd/lightdm/releases/download/%{version}/%{name}-%{version}.tar.xz
#Source1:        https://github.com/CanonicalLtd/lightdm/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source3:        %{name}-greeter.pamd
Source4:        X11-displaymanagers-%{name}
Source5:        gdmflexiserver
Source6:        50-suse-defaults.conf
Source7:        users.conf
Source8:        lightdm.pam
Source9:        lightdm-autologin.pam
Source10:       lightdm.sysusers
Source11:       lightdm.service
# PATCH-FEATURE-OPENSUSE lightdm-sysconfig-support.patch gber@opensuse.org -- Adds support for reading configuration options from /etc/sysconfig/displaymanager and /etc/sysconfig/windowmanager
Patch0:         lightdm-sysconfig-support.patch
# PATCH-FEATURE-OPENSUSE lightdm-xauthlocalhostname-support.patch boo#796230 gber@opensuse.org -- Set XAUTHLOCALHOSTNAME to the hostname for local logins to avoid issues in the session in case the hostname changes
Patch1:         lightdm-xauthlocalhostname-support.patch
# PATCH-FEATURE-OPENSUSE lightdm-set-gdmflexiserver-envvar.patch gber@opensuse.org -- Sets the GDMFLEXISERVER environment variable for the gdmflexiserver wrapper
Patch2:         lightdm-set-gdmflexiserver-envvar.patch
# PATCH-FIX-OPENSUSE lightdm-disable-utmp-handling.patch gber@opensuse.org -- Disable utmp handling since this is handled in the Xstartup/Xreset scripts
Patch3:         lightdm-disable-utmp-handling.patch
# PATCH-FIX-OPENSUSE lightdm-use-run-dir.patch gber@opensuse.org -- Use /run instead of /var/run
Patch4:         lightdm-use-run-dir.patch
# PATCH-FIX-OPENSUSE ignore-known-symlink-sessions.patch boo#1030873 -- Ignore known synlink sessions.
Patch5:         lightdm-ignore-known-symlink-sessions.patch
# PATCH-FIX-UPSTREAM lightdm-1.32.0-qt6-library.patch -- Support Qt6
Patch6:         lightdm-1.32.0-qt6-library.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  sysuser-tools
BuildRequires:  vala
BuildRequires:  xdm
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6DBus)
BuildRequires:  pkgconfig(Qt6Gui)
%if %{build_qt4}
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtDBus)
BuildRequires:  pkgconfig(QtGui)
%endif
BuildRequires:  pkgconfig(gio-2.0) >= 2.26
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.44
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libxklavier)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xdmcp)
%if 0%{?suse_version} < 1600
BuildRequires:  gcc13-c++
%endif
Requires:       gdmflexiserver
# 3rd party greeters don't have to follow
# the same versioning of lightdm.
Requires:       lightdm-greeter
# Uses pam configuration and relies on scripts provided by xdm.
Requires:       xdm
%sysusers_requires
Recommends:     %{name}-lang
# Migrate users from lxdm to lightdm - we only obsolete up to version 0.5.
Obsoletes:      lxdm < 0.5
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(audit)
%endif

%description
LightDM is a lightweight, cross-desktop display manager. Its main
features are a well-defined greeter API allowing multiple GUIs,
support for all display manager use cases, with plugins where
appropriate, low code complexity, and fast performance. Due to its
cross-platform nature greeters can be written in several toolkits
such as Qt and GTK+.

%lang_package

%package -n %{gobject_lib}
Summary:        LightDM GObject-based Client Library
License:        LGPL-2.0-only OR LGPL-3.0-only
Group:          System/Libraries
Recommends:     accountsservice

%description -n %{gobject_lib}
A GObject-based library for LightDM clients to use to interface
with LightDM.

%package gobject-devel
Summary:        Development Files for %{gobject_lib}
License:        LGPL-2.0-only OR LGPL-3.0-only
Group:          Development/Libraries/C and C++
Requires:       %{gobject_lib} = %{version}

%description gobject-devel
This package contains development files needed for developing
GObject-based LightDM clients.

%package -n %{typelibname}
Summary:        GObject Introspection Bindings for the LightDM Client Library
License:        LGPL-2.0-only OR LGPL-3.0-only
Group:          System/Libraries

%description -n %{typelibname}
This package contains the GObject Introspection bindings for the
LightDM client library.

%if %{build_qt4}
%package -n %{qt4_lib}
Summary:        LightDM Qt4-based Client Library
License:        LGPL-2.0-only OR LGPL-3.0-only
Group:          System/Libraries

%description -n %{qt4_lib}
A Qt4-based library for LightDM clients to use to interface with
LightDM.

%package qt-devel
Summary:        Development Files for %{qt4_lib}
License:        LGPL-2.0-only OR LGPL-3.0-only
Group:          Development/Libraries/C and C++
Requires:       %{qt4_lib} = %{version}

%description qt-devel
This package contains development files needed for developing
Qt4-based LightDM clients.
%endif

%package -n %{qt5_lib}
Summary:        LightDM Qt5-based Client Library
License:        LGPL-2.0-only OR LGPL-3.0-only
Group:          System/Libraries
%if !%{build_qt4}
Provides:       %{qt4_lib} = %{version}
Obsoletes:      %{qt4_lib} < %{version}
%endif

%description -n %{qt5_lib}
A Qt5-based library for LightDM clients to use to interface with
LightDM.

%package qt5-devel
Summary:        Development Files for %{qt5_lib}
License:        LGPL-2.0-only OR LGPL-3.0-only
Group:          Development/Libraries/C and C++
Requires:       %{qt5_lib} = %{version}
%if !%{build_qt4}
Provides:       %{name}-qt-devel = %{version}
Obsoletes:      %{name}-qt-devel < %{version}
%endif

%description qt5-devel
This package contains development files needed for developing
Qt5-based LightDM clients.

%package -n %{qt6_lib}
Summary:        LightDM Qt6-based Client Library
License:        LGPL-2.0-only OR LGPL-3.0-only
Group:          System/Libraries

%description -n %{qt6_lib}
A Qt5-based library for LightDM clients to use to interface with
LightDM.

%package qt6-devel
Summary:        Development Files for %{qt6_lib}
License:        LGPL-2.0-only OR LGPL-3.0-only
Group:          Development/Libraries/C and C++
Requires:       %{qt6_lib} = %{version}

%description qt6-devel
This package contains development files needed for developing
Qt6-based LightDM clients.

%package bash-completion
Summary:        Bash completion for lightdm
Group:          System/Shells
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
bash command line completion support for lightdm.

%prep
%autosetup -p1

%build
%if 0%{?suse_version} < 1600
    export CXX=g++-13
%endif
%sysusers_generate_pre %{SOURCE10} lightdm lightdm.conf
export MOC4='%{_bindir}/moc'
export MOC5='%{_libqt5_bindir}/moc'
NOCONFIGURE=1 ./autogen.sh
%configure \
  --disable-static \
  --enable-gtk-doc \
  --with-user-session=default \
  --with-greeter-session=lightdm-default-greeter \
  --with-greeter-user=lightdm
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

# Configuration is delivered in %%{_datadir}/lightdm/lightdm.conf.d
rm %{buildroot}%{_sysconfdir}/lightdm/lightdm.conf

# upstart configuration is not needed.
rm -rf %{buildroot}%{_sysconfdir}/init/

# There is no guest session support in openSUSE.
rm -rf %{buildroot}%{_sysconfdir}/apparmor.d/
rm -rf %{buildroot}%{_libexecdir}/lightdm-guest-session

# These are useless stubs for now.
rm -rf %{buildroot}%{_datadir}/help/

# xdm and xdm-np are used instead.
rm %{buildroot}%{_sysconfdir}/pam.d/lightdm \
   %{buildroot}%{_sysconfdir}/pam.d/lightdm-autologin \
   %{buildroot}%{_sysconfdir}/pam.d/lightdm-greeter
%if 0%{?suse_version} >= 1550
  mkdir -p %{buildroot}%{_pam_vendordir}
  install %{SOURCE8} %{buildroot}%{_pam_vendordir}/lightdm
  install %{SOURCE9} %{buildroot}%{_pam_vendordir}/lightdm-autologin
  install -Dpm 0644 %{SOURCE3} %{buildroot}%{_pam_vendordir}/lightdm-greeter
%else
  install %{SOURCE8} %{buildroot}%{_sysconfdir}/pam.d/lightdm
  install %{SOURCE9} %{buildroot}%{_sysconfdir}/pam.d/lightdm-autologin
  install -Dpm 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/pam.d/lightdm-greeter
%endif

ln data/lightdm.conf data/lightdm.conf.example

install -d %{buildroot}%{_sysconfdir}/xdg/lightdm/lightdm.conf.d
install -d %{buildroot}%{_datadir}/lightdm/greeters
install -d %{buildroot}%{_datadir}/lightdm/lightdm.conf.d
install -d %{buildroot}%{_datadir}/lightdm/remote-sessions
install -d %{buildroot}%{_datadir}/lightdm/sessions
install -d %{buildroot}%{_datadir}/xgreeters
install -d %{buildroot}%{_localstatedir}/cache/lightdm
install -d %{buildroot}%{_localstatedir}/lib/lightdm
install -d %{buildroot}%{_localstatedir}/lib/lightdm-data
install -d %{buildroot}%{_localstatedir}/log/lightdm
install -d %{buildroot}%{rundir}/lightdm

install -Dpm 0644 %{SOURCE4} %{buildroot}%{_prefix}/lib/X11/displaymanagers/lightdm
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-displaymanager
ln -s %{_sysconfdir}/alternatives/default-displaymanager %{buildroot}%{_prefix}/lib/X11/displaymanagers/default-displaymanager

install -Dpm 0755 %{SOURCE5} %{buildroot}%{_libexecdir}/lightdm/gdmflexiserver

install -Dpm 0644 %{SOURCE6} %{buildroot}%{_datadir}/lightdm/lightdm.conf.d/50-suse-defaults.conf
install -Dpm 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/lightdm/users.conf

%if !%{defined _distconfdir} || 0%{?suse_version} < 1550
sed -e 's-/usr/etc-%{_sysconfdir}-g' -i %{buildroot}%{_datadir}/lightdm/lightdm.conf.d/50-suse-defaults.conf
%endif

install -Dm0644 %{SOURCE10} %{buildroot}%{_sysusersdir}/lightdm.conf
install -Dm0644 %{SOURCE11} %{buildroot}%{_unitdir}/lightdm.service

%find_lang %{name} %{?no_lang_C}

%pre -f lightdm.pre
%service_add_pre %{name}.service
for i in pam.d/lightdm pam.d/lightdm-autologin pam.d/lightdm-greeter; do
  test -f /etc/${i}.rpmsave && mv -v /etc/${i}.rpmsave /etc/${i}.rpmsave.old ||:
done

%posttrans
# Migration to /usr/etc.
for i in pam.d/lightdm pam.d/lightdm-autologin pam.d/lightdm-greeter; do
  test -f /etc/${i}.rpmsave && mv -v /etc/${i}.rpmsave /etc/${i} ||:
done

%post
%service_add_post %{name}.service
# Special trick: migrate users from lxdm to lightdm
# see https://lists.opensuse.org/opensuse-factory/2016-07/msg00417.html
. %{_sysconfdir}/sysconfig/displaymanager
if [ -z "$DISPLAYMANAGER" -o "$DISPLAYMANAGER" = "lxdm" ] ; then
    sed -i 's/^DISPLAYMANAGER=".*"/DISPLAYMANAGER="lightdm"/' %{_sysconfdir}/sysconfig/displaymanager
fi
%{_sbindir}/update-alternatives --install %{_prefix}/lib/X11/displaymanagers/default-displaymanager \
  default-displaymanager %{_prefix}/lib/X11/displaymanagers/lightdm 15

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun_without_restart %{name}.service
if [ "$1" -eq 0 ]; then
    . %{_sysconfdir}/sysconfig/displaymanager
    if [ "$DISPLAYMANAGER" == "lightdm" ] ; then
        sed -i 's/^DISPLAYMANAGER="lightdm"/DISPLAYMANAGER=""/' %{_sysconfdir}/sysconfig/displaymanager
    fi
fi
[ -f %{_prefix}/lib/X11/displaymanagers/lightdm ] || %{_sbindir}/update-alternatives \
  --remove default-displaymanager %{_prefix}/lib/X11/displaymanagers/lightdm

%post -n %{gobject_lib} -p /sbin/ldconfig

%postun -n %{gobject_lib} -p /sbin/ldconfig

%if %{build_qt4}
%post -n %{qt4_lib} -p /sbin/ldconfig

%postun -n %{qt4_lib} -p /sbin/ldconfig
%endif

%post -n %{qt5_lib} -p /sbin/ldconfig

%postun -n %{qt5_lib} -p /sbin/ldconfig

%post -n %{qt6_lib} -p /sbin/ldconfig

%postun -n %{qt6_lib} -p /sbin/ldconfig

%files
%license COPYING.GPL3
%doc NEWS data/lightdm.conf.example
%{_bindir}/dm-tool
%{_sbindir}/lightdm
%dir %{_libexecdir}/lightdm/
%{_libexecdir}/%{name}/gdmflexiserver
%dir %{_sysconfdir}/xdg/lightdm/
%dir %{_sysconfdir}/xdg/lightdm/lightdm.conf.d/
%dir %{_sysconfdir}/lightdm/
%config(noreplace) %{_sysconfdir}/lightdm/users.conf
%config(noreplace) %{_sysconfdir}/lightdm/keys.conf
%if 0%{?suse_version} >= 1550
%{_pam_vendordir}/lightdm
%{_pam_vendordir}/lightdm-autologin
%{_pam_vendordir}/lightdm-greeter
%else
%config %{_sysconfdir}/pam.d/lightdm
%config %{_sysconfdir}/pam.d/lightdm-autologin
%config %{_sysconfdir}/pam.d/lightdm-greeter
%endif
%{_datadir}/dbus-1/system.d/org.freedesktop.DisplayManager.conf
%dir %{_prefix}/lib/X11/displaymanagers/
%{_prefix}/lib/X11/displaymanagers/lightdm
%{_prefix}/lib/X11/displaymanagers/default-displaymanager
%ghost %{_sysconfdir}/alternatives/default-displaymanager
%{_datadir}/lightdm/
%dir %{_datadir}/accountsservice/
%dir %{_datadir}/accountsservice/interfaces/
%{_datadir}/accountsservice/interfaces/org.freedesktop.DisplayManager.AccountsService.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.DisplayManager.AccountsService.xml
%{_datadir}/polkit-1/actions/org.freedesktop.DisplayManager.AccountsService.policy
%dir %{_datadir}/xgreeters/
%ghost %attr(711,lightdm,lightdm) %dir %{rundir}/lightdm/
%attr(750,lightdm,lightdm) %dir %{_localstatedir}/log/lightdm/
%attr(750,lightdm,lightdm) %dir %{_localstatedir}/lib/lightdm/
%attr(750,lightdm,lightdm) %dir %{_localstatedir}/lib/lightdm-data/
%attr(711,root,root) %dir %{_localstatedir}/cache/lightdm/
%{_mandir}/man1/lightdm.1%{?ext_man}
%{_mandir}/man1/dm-tool.1%{?ext_man}
%{_sysusersdir}/lightdm.conf
%{_unitdir}/lightdm.service

%files lang -f %{name}.lang

%files -n %{gobject_lib}
%license COPYING.LGPL2 COPYING.LGPL3
%{_libdir}/lib%{gobject_libname}.so.*

%files gobject-devel
%{_libdir}/lib%{gobject_libname}.so
%{_libdir}/pkgconfig/lib%{gobject_libname}.pc
%{_includedir}/%{gobject_libname}/
%{_datadir}/gir-1.0/LightDM-1.gir
%dir %{_datadir}/vala/vapi/
%{_datadir}/vala/vapi/lib%{gobject_libname}.*
%doc %{_datadir}/gtk-doc/html/%{gobject_libname}/

%files -n %{typelibname}
%{_libdir}/girepository-1.0/LightDM-1.typelib

%if %{build_qt4}
%files -n %{qt4_lib}
%license COPYING.LGPL2 COPYING.LGPL3
%{_libdir}/lib%{qt4_libname}.so.*

%files qt-devel
%{_libdir}/lib%{qt4_libname}.so
%{_libdir}/pkgconfig/lib%{qt4_libname}.pc
%{_includedir}/%{qt4_libname}/
%endif

%files -n %{qt5_lib}
%license COPYING.LGPL2 COPYING.LGPL3
%{_libdir}/lib%{qt5_libname}.so.*

%files qt5-devel
%{_libdir}/lib%{qt5_libname}.so
%{_libdir}/pkgconfig/lib%{qt5_libname}.pc
%{_includedir}/%{qt5_libname}/

%files -n %{qt6_lib}
%license COPYING.LGPL2 COPYING.LGPL3
%{_libdir}/lib%{qt6_libname}.so.*

%files qt6-devel
%{_libdir}/lib%{qt6_libname}.so
%{_libdir}/pkgconfig/lib%{qt6_libname}.pc
%{_includedir}/%{qt6_libname}/

%files bash-completion
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/dm-tool
%{_datadir}/bash-completion/completions/lightdm

%changelog
* Sun May 25 2025 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Leap 15: Use gcc 13
* Thu May 15 2025 Hillwood Yang <hillwood@opensuse.org>
- Add lightdm-1.32.0-qt6-library.patch, support Qt6
* Tue Mar 25 2025 Callum Farmer <gmbr3@opensuse.org>
- Add lightdm.service to prepare for systemd control of display
  manager choice
* Sun Aug 25 2024 sb56637 <mxoo28j7@duck.com>
- Added /usr/sbin/nologin to hidden-shells to prevent "Dynamic User" from appearing in user list
* Fri Jul 12 2024 Martin Jambor <mjambor@suse.com>
- Add typecasts to avoid passing incompatible pointer types to
  opensuse_sysconfig_get_string and opensuse_sysconfig_get_boolean to
  our patch lightdm-sysconfig-support.patch so that the package
  compiles with compilers which by default enforce C99 standard such
  as GCC 14. [boo#1221704]
* Thu Mar 16 2023 Callum Farmer <gmbr3@opensuse.org>
- Split bash-completion to separate sub-package
* Tue Aug  9 2022 Thorsten Kukuk <kukuk@suse.com>
- Use %%_pam_vendordir
* Tue Aug  2 2022 Dirk Müller <dmueller@suse.com>
- update to 1.32.0:
  * Overwrite existing X authority files to avoid corruption
  * Change logind-check-graphical default config value to true
  * Block autologin if shell in nologin or false
  * Fix failure if with greeters sending two login requests quickly.
  * Drop Qt 4 support, it's been unsupported since 2015
  * Fix lightdm_set_layout
  * Improve method of determining a session is Wayland
  * Don't call setenv with a NULL value - the behaviour is undefined
  * Replace deprecated QAbstractItemModel::setRoleNames
  * Move D-Bus conf file to $(datadir)/dbus-1/system.d (bsc#1205939)
  * Fix tests failing when compiled with --with-greeter-user
  * Use Python 3 in tests
  * Disable compiler optimizations for test programs
  * Compilation fix for glibc 2.33
  * Remove deprecated use of G_TYPE_INSTANCE_GET_PRIVATE, G_PARAM_PRIVATE
  * Fix compile failure due to use of clearenv on FreeBSD
  * Use a size_t to resolve a compile warning
  * Fix DesktopManager typo in man page
- drop lightdm-glibc-2.33-fix.patch (upstream)
* Fri Dec 31 2021 Callum Farmer <gmbr3@opensuse.org>
- Change to systemd-sysusers
* Tue Oct 19 2021 Max Lin <mlin@suse.com>
- Replace /usr/etc to /etc for products if suse_version < 1550
  (bsc#1190289)
* Fri May 21 2021 Ludwig Nussel <lnussel@suse.de>
- Remove %%ghost from /var/cache/lightdm. With SELinux enabled
  lightdm would otherwise not be allowed to create that directory.
* Mon Feb  8 2021 Martin Liška <mliska@suse.cz>
- Add lightdm-glibc-2.33-fix.patch that fixes issue with glibc 2.33
  (boo#1181778).  The patch was suggested as gh#168.
* Wed Dec  9 2020 Antonio Larrosa <alarrosa@suse.com>
- Only build the qt4 subpackage up to Leap 15.2 / SLE 15 SP2
  (boo#1179613)
* Sat Oct  3 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Change paths from /etc to /usr/etc for UsrEtc Move (boo#1177197)
* Tue Sep 29 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fixup pam stack a bit more (boo#1176338):
  + Do not create hardlinks between lightdm pam files and xdm's pam
    files, but install explicit lightdm pam stack that @includes
    xdm. This has the advantage that, if an admin creates
    /etc/pam.d/xdm, we will follow this right away. With the
    hardlinks, the /usr/etc/pam.d/xdm would still be used, which
    might not be the expected outcome.
* Thu Sep 17 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Follow XDM's change of moving the default pam config file to
  /usr/etc (boo#1176338).
- Add pre/posttrans scripts to ensure user modified
  /etc/pam.d/lightdm* survives our move to /usr/etc (and user
  modification in /etc/pam.d wins over /usr/etc/pam.d).
* Tue Jul  7 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec
* Tue Sep 17 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.30.0:
  * Add lightdm_user_get_is_locked ().
  * Hide users with shell /bin/false.
  * Remove unity-system-compositor support (dead upstream).
  * Fix dm-tool crash.
  * Update documentation.
- Refresh patches with quilt.
- Use modern macros.
* Thu Jul 18 2019 Wolfgang Bauer <wbauer@tmo.at>
- Fix Provides/Obsoletes of the lightdm-qt5-devel subpackage
* Fri May  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Stop building lightdm-qt4 on openSUSE > 1500.
* Thu Oct 25 2018 sor.alexei@meowr.ru
- Update to version 1.28.0:
  * Continue to shutdown session if removing X authority fails.
  * Set XDG_SEAT env variable in script hooks.
  * Fix small leak in XDMCP server.
  * liblightdm-qt: Mark class PowerInterface as exported.
  * Fix one qt5 test being run instead of a qt4 one.
  * Remove use of deprecated g_type_class_add_private.
  * Modernise private data in objects.
  * Document XDG_SEAT_PATH in man page.
  * Fix install failing if link already exists.
  * Remove bashisms in configure.ac.
- Rebase lightdm-sysconfig-support.patch,
  lightdm-xauthlocalhostname-support.patch.
- Use GPG signing.
* Thu Apr 12 2018 sor.alexei@meowr.ru
- Update to version 1.26.0:
  * Fix build system to require C99.
  * Support moc being called moc-qt5.
  * Fail configure if MOC can't be found.
  * Use AccountsService extension system for extended greeter
    information.
  * Fix incorrect use of ConsoleKit CanSuspend/Hibernate API.
  * Use standard format for arguments passed to qtchooser.
  * Modernise code style.
- Rebase lightdm-disable-utmp-handling.patch,
  lightdm-set-gdmflexiserver-envvar.patch,
  lightdm-sysconfig-support.patch,
  lightdm-xauthlocalhostname-support.patch.
- Rename and rebase lightdm-ignore-known-symlink-sessions.patch.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.24.1:
  * Fixes for VNC and XDMCP connections (boo#1066708, boo#1083161).
  * Set names for XDMCP and VNC seats.
  * Expose autologin-session as a hint to the greeter.
  * Fix timed autologins not using autologin-session when no
    session specified.
- Enable libaudit support on Leap 15.0 or newer.
* Thu Oct 12 2017 dimstar@opensuse.org
- Have update-alternatives handle Xinit's integration of the
  displaymanager, replacing /etc/sysconfig/displaymanager
  (boo#1053863).
* Sat Sep 23 2017 sor.alexei@meowr.ru
- Update to version 1.24.0:
  * No changes.
* Fri Jul 21 2017 dimstar@opensuse.org
- Update lightdm-sysconfig-support.patch: deprecate the use of
  DEFAULT_WM in /etc/sysconfig/windowmanager. The new way of
  setting the system default WM is by means of update-alternatives,
  handling the /usr/share/xsessions/default.desktop (boo#1030873).
* Tue Jul  4 2017 fvogt@suse.com
- Augment patch to also resolve the target of symlink sessions
  for detemining the preselected option:
  * ignore-known-symlink-sessions.patch
* Tue May 16 2017 fvogt@suse.com
- Add patch to support new autologin mechanism needed for the
  role-based desktop selection (boo#1030873):
  * ignore-known-symlink-sessions.patch
- Use "default" instead of "twm" as default session
* Wed Apr  5 2017 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Allow guest sessions to talk to Mir.
* Thu Feb 23 2017 sor.alexei@meowr.ru
- Update to version 1.21.5 (changes since 1.21.3):
  * Use power management functions from ConsoleKit2 if available.
  * Correctly pass return value from sessions to LightDM.
  * Retry VT_WAITACTIVE if we get EINTR.
  * Ignore SIGHUP by default.
  * Use SA_RESTART with SIGPIPE.
  * liblightdm-qt: Use liblightdm-gobject power methods instead of
    re-implementing in Qt.
- Rebase lightdm-disable-utmp-handling.patch.
* Wed Jan 25 2017 sor.alexei@meowr.ru
- Update to version 1.21.3 (changes since 1.21.1):
  * Use SA_RESTART on signals so we don't get interrupted reads.
  * Use logind to terminate greeter sessions if it is available.
  * Load greeters from XDG_DATA_DIRS instead of the compile time
    value.
  * Allow the D-Bus interface to be disabled.
  * Always pass through LD_PRELOAD, LD_LIBRARY_PATH and PATH to
    sessions/display servers.
  * Fix an incorrect unref in the XDMCP server code.
  * Fix logging warnings.
- Rebase lightdm-sysconfig-support.patch.
* Mon Nov 28 2016 sor.alexei@meowr.ru
- Update to version 1.21.1 (changes since 1.20.0):
  * Add liblightdm functions for getting OS release information
    and the message of the day.
  * Warn if we find unknown keys in configuration.
  * Fix .profile errors not showing in .xsession-errors log.
  * Remove a duplicate Qt property in liblightdm.
  * Fix and improve liblightdm API documentation.
  * Minor GIR annotation fixes.
  * Fix greeters crashing with unknown configuration keys
    (regression from 1.12.0)
  * Add an API verison to the greeter-daemon protocol for future
    enhancements.
  * More regression tests.
* Sat Oct 15 2016 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * No changelog available.
* Sat Oct  1 2016 sor.alexei@meowr.ru
- Update to version 1.19.5:
  * Fix errors in documentation generation.
  * Improve documentation.
  * Fix guest AppArmor profile to allow guest sessions more access
    to the upstart session socket.
  * Fix a small memory leak in liblightdm-gobject keyboard layout
    code.
- Rerebase lightdm-sysconfig-support.patch (boo#1002061).
- Better X11-displaymanagers-lightdm.
- Remove lightdm-rpmlintrc.
* Sun Sep 25 2016 sor.alexei@meowr.ru
- Update to version 1.19.4 (changes since 1.19.0):
  * Rename "xlocal" seat type to "local". Using "xlocal" will
    continue to work but will report a warning.
  * Fix memory leaks.
  * Fix uninitialised memory errors.
  * Use MIR_SERVER_HOST_SOCKET instead of MIR_SOCKET to report
    compositor socket to sessions. This used to work but no longer
    works in Mir 0.21
  * Allow XMir to run on the xlocal seat using the new
    x-server-backend=mir option.
  * Use only a single compositor on local seats.
  * Fix Mir greeter log filename having "(null)" in the name.
  * Copy fcitx/mozc rules so session works when these aren't
    installed.
  * Revert lxsession change - it caused the AppArmor to fail to
    compile.
  * Add support for greeters running inside sessions. This is
    enabled by setting X-LightDM-Allow-Greeter inside the session
    .desktop file.
    The session can then use liblightdm to connect one greeter to
    the daemon. The communication is done using a socket
    (/var/run/lightdm/<user>/greeter-socket) that is accessible to
    any process ran by that user. Consider controlling access to
    this socket using a MAC system such as AppArmor.
  * Report errors for all liblightdm methods. This will require
    existing greeters to update their API usage. The ABI is
    unchanged.
  * Handle EAGAIN correctly when daemons communicate with the
    daemon.
  * Drop support for mir-container sessions - no-one ever used these.
  * Fix in-session greeters not working for greeter logins.
  * Fix various issues in new in-session greeter code.
  * Fix user list memory management exposed by use of in-session
    greeters.
  * Fix some spurious warnings in the log.
- Rebase lightdm-sysconfig-support.patch,
  lightdm-xauthlocalhostname-support.patch.
- Use tarball signing.
* Thu Jul 28 2016 dimstar@opensuse.org
- Add code to %%post to migrate users of no longer maintained
  'lxdm' display manager over to 'lightdm'.
- Obsolete lxdm up to version 0.5 (we never carried 0.5 in any
  openSUSE product).
* Sun Jun 19 2016 mimi.vx@gmail.com
- remove user-authority-in-system-dir=true from suse conf, fixes
  boo#976876
* Sat May  7 2016 sor.alexei@meowr.ru
- Update to version 1.19.0:
  * Use /dev/tty0 instead of /dev/console for VT operations.
  * Don't quit on SIGUSR1, SIGUSR2 or SIGHUP.
  * Improve XDMCP IPv6 address selection.
  * Set XDMCP hostname field in to system hostname or configured
    value.
  * Allow fcitx and mozc to run in guest session.
  * Fix lxsession running in guest session.
  * Drop support for legacy XMir.
  * Fix g_spawn compiler warning.
- Don't configure twice.
- Enable Vala bindings.
- Drop support for openSUSE older than 13.2.
- Some spec cleanup.
* Mon Apr 11 2016 mimi.vx@gmail.com
- fix config file to use new Seat:* sematics
* Sun Apr 10 2016 mimi.vx@gmail.com
- update to 1.18.1
  * Use /dev/tty0 instead of /dev/console for VT operations
  * Small documentation fixes
  * Don't write $DISPLAY into tty line in utmp/btmp.
* Fri Mar  4 2016 mimi.vx@gmail.com
- update to 1.17.5
  * Set XDG_RUNTIME_DIR for ConsoleKit sessions. This is a recent change in
    ConsoleKit2.
  * Add support for g_autoptr and liblightdm-gobject
  * Fix dm-tool add-local-seat not working because LightDM is trying to
    connect with TCP/IP
* Thu Jan  7 2016 mimi.vx@gmail.com
- fix boo#960924
- modify lightdm-sysconfig-support.patch to use new Seat sematics
* Sat Jan  2 2016 mimi.vx@gmail.com
- update to 1.17.3
- refresh patches:
  lightdm-disable-utmp-handling.patch
  lightdm-set-gdmflexiserver-envvar.patch
  lightdm-sysconfig-support.patch
  lightdm-use-run-dir.patch
  lightdm-xauthlocalhostname-support.patch
  * Don't enable the hardware cursor in Unity System Compositor anymore.
    Unity 8 now correctly provides its own cursor and other shells should too
  * Handle XDMCP Request packet with no addresses.
  * Don't start LightDM if the XDMCP server is configured with a key that
    doesn't exist.
  * Add IP addresses to XDMCP log messages.
  * Refactor XDMCP error handling.
  * Add more XDMCP tests.
  * Add a backup-logs option that can be used to disable existing logging
    files having a .old suffix added to them.
  * Add LC_PAPER, LC_NAME, LC_ADDRESS, LC_TELEPHONE, LC_MEASUREMENT and
    LC_IDENTIFICATION variables to the list of inherited locale variables.
  * Implement XDMCP ForwardQuery.
  * Fix small memory leak in XDMCP logging code.
  * Disable log backups - this interferes with logrotate.
  * Support using libaudit to generate audit events.
  * Handle trailing whitespace on boolean values in configuration.
  * Update example configuration to more correctly match allowed options.
  * Fix unnecessary X server from being launched when locking seats.
  * Check the version of the X server we are running so we correctly pass
  - listen tcp when required.
  * Allow reading /proc/<PID>/net/dev from within a guest session.
  * Allow guest sessions to write in /{,var/}run/screen folder.
  * Update guest-session AppArmor profile to be suitable for openSUSE.
  * Fix apparmor profiles for running Chromium in guest sessions.
  * Fix configure failing without Vala installed.
  * Update default configuration better explaining the seat configuration name
    matching and dropping references to the obsolete [SeatDefaults] section
  * Drop Xorg option -sharevts. It's no longer required for non-seat0 X
    servers since xorg-server release 1.16.
  * Support Wayland sessions.
  * Implement autologin-session option.
  * Generate Vala bindings from GIR instead of manually writing them. This
    fixes some small bugs in both the Vala and GIR bindings.
  * Don't remove autotools generated files in distclean.
  * Fix default X server command set to XMir in 1.15.0.
  * Internally merge the [SeatDefaults] and [Seat:*] sections together. The
    previous method meant configuration snippets using a mix of old and new
    naming would not correctly override eachother.
  * Use IP address of XDMCP requests to contact X server if available.
  * Add an option for XDMCP and VNC servers to only listen on one address.
  * Fix configuration file warnings so they go to the log, not stderr.
  * Warn if deprecated options logind-load-seats or xdg-seat are in
    configuration.
  * Improve IP addresses in XDMCP log messages.
  * Fix typo in dm-tool man page.
* Wed Sep 23 2015 sndirsch@suse.com
- displaymanager default setting in %%post/postun:
  * don't limit it to openSUSE >= 13.1 (has been done accidently)
  * make sure not to replace DISPLAYMANAGER in comments
  * only reset DISPLAYMANAGER to "" when uninstalling lightdm,
    not also in the update case (OMG!)
  * ldconfig is not required at all for the main package
* Mon Sep 14 2015 bhertwig@suse.com
- Set displaymanager to lightdm if displaymanager variable is unset
  (FATE #319432)
* Tue Jul  7 2015 mimi.vx@gmail.com
- update to 1.15.0
  * Deprecate [SeatDefaults] in favour of [Seat:*]
* Thu Apr  9 2015 peter@itwm.fhg.de
- fix XDMCP setting in lightdm-sysconfig-support.patch: Setting
  DISPLAYMANAGER_XSERVER_TCP_PORT_6000_OPEN=true forced LightDM to
  open port 6000 for XDMCP protocol (instead of its default port
  177). As a consequence, usual X11 terminals weren't able to
  contact the XDM service. However, this sysconfig setting should
  only request the XServer to open port 6000 for requests to a
  running X11 session and leave the XDMCP port unchanged.
* Tue Mar 24 2015 gber@opensuse.org
- update to version 1.14.0
  - Initialize file descriptor handles so we don't attempt to close
    stdin by accident
  - Fix small errors detected by scan-build (clang)
  - Fix pipe file descriptor leak for each greeter session
  - Support active session changing via logind
  - Don't allow liblightdm-gobject to be disabled. It is required
    for liblightdm-qt and the tests so it's not worth supporting
    builds without it
  - Add bash autocompletion support
  - Don't attempt generate D-Bus seat/session removal signals on
    shutdown
  - Add missing method QLightDM::Greeter::cancelAutologin
  - Fix crash when having configuration keys defined in multiple
    places
  - Fix pipe file descriptor leak for each session login /
    authentication
  - Use correct syntax for DesktopNames key in session files
  - Match seat configuration with globbing
  - Allow user switching in multi-seat until bug stopping greeter
    showing on logout is fixed
  - Disable log message when AccountsService users change
  - Update AppArmor scripts, requires AppArmor 2.9
  - Update tests to run better on servers
* Tue Mar 10 2015 gber@opensuse.org
- update to version 1.12.3
  - fix pipe file descriptor leak for each greeter session
  - don't attempt generate D-Bus seat/session removal signals on
    shutdown
* Thu Nov 13 2014 gber@opensuse.org
- update to version 1.12.1
  - Fix pipe file descriptor leak for each session login /
    authentication
  - Use correct syntax for DesktopNames key in session files
  - Mock /run in tests
* Mon Nov  3 2014 gber@opensuse.org
- use symlinks to the xdm PAM service files again, using a
  different PAM service name breaks automatic unlocking of
  gnome-keyring via PAM (bnc#903744)
* Wed Oct  8 2014 gber@opensuse.org
- remove allow-user-switching=true from 50-suse-defaults.conf,
  this is now the temporary default
* Wed Oct  8 2014 gber@opensuse.org
- update to version 1.12.1
  - Fix crash when having configuration keys defined in multiple
    places
  - Allow user switching in multi-seat until bug stopping greeter
    showing on logout is fixed
  - Disable log message when AccountsService users change
* Thu Oct  2 2014 lbsousajr@gmail.com
- Add option allow-user-switching=true to 50-suse-defaults.conf.
  It's a temporary workaround until upstream bug #1371250
  (https://bugs.launchpad.net/lightdm/+bug/1371250) is fixed.
- Drop option logind-load-seats=true from 50-suse-defaults.conf.
  It's only required for 1.10 series, where automatic multiseat
  support (backported from 1.12 series) was made optional.
* Tue Sep 30 2014 gber@opensuse.org
- update to version 1.12.0
  - Fix assumption that the display server is X when running scripts.
  - Don't access .dmrc files until information from these files is
    required.
  - Don't check the logind CanGraphical seat property unless
    login-check-graphical option is set to true. There are too many
    cases of drivers that don't set the appropriate flags for this
    feature to work.
  - Make socket writing code used between greeter and daemon more
    robust to errors.
  - Fix small memory leaks.
  - Improve logging messages.
  - Test improvements.
  - Rework logind code that gets session ID. The previous method
    was racy and a change in lightdm 1.11.7 led to a lockup when
    this race occurred.
  - Handle CanGraphical property on logind seats
  - Use logind to provide the list of seats to use. Deprecate the
    old method of manually defining seats.
  - Add --show-config option that shows combined configuration.
  - Drop the surfaceflinger seat type. This was a temporary
    solution while Ubuntu Phone was migrating to Mir.
  - Add a seat option 'allow-user-switching' that can disable all
    user switching for that seat
  - Add a new session type 'mir-container' that allows the session
    to run inside a custom system compositor
  - Only seat0 takes VT from Plymouth
  - Removed unused GAsyncResultIface.is_tagged as this attribute
    was not available in earlier versions of Glib I/O.
  - Abort autogen if yelp-tools not installed
  - Return correct errors for D-Bus calls
  - Make PAM services configurable
  - Do timed autologin each time you are returned to the greeter
  - Fix tests failing with Qt 5.3 due to it checking getuid/geteuid
    which we are faking
  - dm-tool: Warn if trying to switch to user without username
  - Fix Mir sessions broken with unity-system-compositor 0.3.
  - Add back Vala bindings for LightDM.Greeter.connect_sync - just
    mark as deprecated.
  - Put unity-system-compositor's mir_socket under /run rather than
    /tmp.
  - Fix building with clang (3.5) and -Werror.
  - Correct section name in default users.conf file.
  - Add liblightdm method to get user UID
  - DBus-activate logind
  - Check for libgcrypt at configure time
  - Allow greeters to remain runing to reduce startup time when
    switching to a greeter
  - Add asynchronous methods to liblightdm
  - When switching to an existing session refresh PAM credentials
    and end session cleanly so no resources leak.
  - Support new standard DesktopNames field in session files
  - Set XDG_SESSION_TYPE and XDG_SESSION_DESKTOP as used by systemd
  - Emit DBus PropertiesChanged when Sessions/Seats properties
    change. Also add SessionAdded/SessionRemoved signals to Seat
    interface
* Wed Sep 17 2014 gber@opensuse.org
- update to version 1.10.2
  - Use logind to provide the list of seats to use
  - Fix crash if running script hooks with non-X display servers
  - Add a seat option 'allow-user-switching' that can disable all
    user switching for that seat
  - Make PAM services configurable
  - Add liblightdm method to get user UID
  - Add a new session type 'mir-container' that allows the session
    to run inside a custom system compositor
  - Add --show-config option that shows combined configuration
  - Use XDG_SESSION_ID from PAM instead of using the logind D-Bus
    API
  - Make socket writing code used between greeter and daemon more
    robust to errors
  - Correct section name in default users.conf file
  - Fix tests failing with Qt 5.3 due to it checking
    getuid/geteuid which we are faking
  - Fix small memory leaks
  - Test improvements
- fix users.conf section name
- enable logind multiseat by default
- configure lightdm to use the xdm PAM services directly instead of
  symlinking them
* Sat May 31 2014 gber@opensuse.org
- split off subpackage with the GObject Introspection bindings
* Mon Apr 28 2014 gber@opensuse.org
- update to version 1.10.1
  - When switching to an existing session refresh PAM credentials
    and end session cleanly so no resources leak
  - Update apparmor rules to allow oxide based browsers and Google
    Chrome to run in the guest session
* Tue Apr  8 2014 gber@opensuse.org
- update to version 1.10.0
  - Fix return value for Vala bindings to
    Greeter.start_session_sync
  - Fix logging when failing to find session
  - Update the lightdm AppArmor abstraction to allow the guest
    session to start when AppArmor is mediating signals and ptrace
    and fix a minor, but noisy, denial when applications attempt to
    read /proc/<PID>/stat
  - Pass --enable-hardware-greeter to unity-system-compositor for
    Mir sessions on xlocal seats
  - Handle not getting an X connection when attempting to get X
    layouts
  - Read config data from both XDG_DATA_DIRS and XDG_CONFIG_DIRS
  - Ensure X authority is written before X server is started
  - Activate after unlocking a logind session
  - Don't use g_hash_table_get_keys_as_array, it's a glib 2.40
    feature
  - Honour session type requested by greeter for guest sessions
  - Log to wtmp and btmp
  - Implement guest-session config option
  - Handle signals being received in child processes instead of
    treating them like they are received in the daemon
  - Set utmp ut_line to the display name (i.e. :0) to match what
    other programs expect (e.g. 'w')
  - Fix lightdm_greeter_ensure_shared_data_dir_sync returning the
    wrong value
  - Fix shared data tests so you can run test suite without root
    again
  - Be extra careful not to call any non thread safe function after
    a fork
  - Fix some small memory leaks detected by valgrind
  - Fix process shutdown code to stop generating confusing warnings
  - Fix more double removal of source IDs
  - Test improvements
  - Add support for shared user data directories between the
    greeter and user sessions
  - Refactor LightDMUser and User classes to use the same code
    internally
  - Correctly invoke PAM to change authentication token
  - Make xdg-seat a core property of a seat and always pass it to X
    servers
  - Qt bindings: properly hand over prompt and message type
  - Add warning flags where they are missing and fix the resulting
    warnings
  - Support Mir sessions in xlocal seats by starting a unity system
    compositor for each session
  - Add --screen and --fullscreen options to "dm-tool
    add-nested-seat"
  - Don't try to compile liblightdm-qt if liblightdm-gobject will
    not be compiled
  - Stop greeters warning if sessions directories not present or
    lightdm.conf doesn't exist - this is valid
  - Fix log name for Mir display servers
  - Fix double removal of source IDs
  - In the unity seat, if we don't have proper VT support, fake VT
    0 instead of a real VT number. This matches what logind expects
  - Fix issue where VTs are double used when switching sessions
  - Remove lightdm-set-defaults and gdmflexiserver
  - Add new ability to specify a list of seat types to try, rather
    than just one
  - Allow Mir sessions in the surfaceflinger seat
  - Rename the guest session wrapper to have a simpler name
  - Make sure sessions are associated with the display server
    before starting them
  - Add a dm-tool man page
  - Don't pass system user accounts from AccountsService to
    greeters
  - Fix crash if switching to greeter and it isn't installed
  - Implement missing guest-wrapper functionality and enable it for
    Ubuntu
  - Update AppArmor scripts to work in Ubuntu 13.10
  - Correctly set $XDG_SESSION_CLASS for greeters. This was
    regressed in 1.7.5 for ConsoleKit and was never passed to
    logind. logind/ConsoleKit treat greeter sessions without this
    set as user sessions. This causes greeters to show the lightdm
    user able to be logged in with
  - Set $USER when running the session-setup-script. This is a
    regression from 1.7.5
  - Fix notification of sessions being logged out. This is a
    regression from 1.7.5 and caused greeters to show sessions
    logged in after they had been logged out
  - Refactor liblightdm user scanning to be simpler and more
    reliable. This fixes bugs where some properties wouldn't be
    updated when they changed in accounts service
  - Add support for a "display-stopped-script" field in
    lightdm.conf. The "display-stopped-script" field allows us to
    run a script right after stopping the display server
  - Allow dm-tool to run outside of a session if it doesn't need to
    be
  - Set $MIR_SERVER_NAME to assign a name to launched sessions.
    Also use a "greeter-" prefix for greeter sessions for the
    benefit of unity-system-compositor
  - Fix crash when starting with existing X servers. This was
    introduced in rev 1651 (lightdm 1.7.0)
  - Fix crash where Process objects are accessed after unref
- add back gdmflexiserver script and drop the obsolete
  lightdm-lock-screen-before-switch.patch
- do not install an %%{_sysconfdir}/lightdm/lightdm.conf any more,
  rather move it to %%_defaultdocdir/lightdm/lightdm.conf.example
  since it contains a reference of all configuration options
* Thu Mar 13 2014 gber@opensuse.org
- update to version 1.8.8
  - Handle signals being received in child processes instead of
    treating them like they are received in the daemon
  - Ensure X authority is written before X server is started
    (bnc#846832, lp#1260220)
  - Honour session type requested by greeter for guest sessions
  - Fix some small memory leaks detected by valgrind
  - Fix double removal of source IDs
* Thu Feb 27 2014 gber@opensuse.org
- only build-depend on Qt5 for >= 13.1
* Thu Feb 27 2014 gber@opensuse.org
- drop support for openSUSE < 12.3
- do not overwrite lightdm.conf, users.conf, keys.conf by default
- make use of lightdm.conf.d, put openSUSE-specific configuration
  in /usr/share/lightdm/lightdm.conf.d and drop
  lightdm-default-configuration.patch
- remove useless usermod call
* Fri Feb 21 2014 hrvoje.senjan@gmail.com
- Enable Qt5 version build of the library for >= 13.1
* Thu Feb  6 2014 gber@opensuse.org
- update to version 1.8.7
  - Correctly invoke PAM to change authentication token
* Thu Jan 23 2014 gber@opensuse.org
- simplify lightdm-xauthlocalhostname-support.patch
* Wed Jan 22 2014 gber@opensuse.org
- update to version 1.8.6
  - Fix issue where VTs are double used when switching sessions
* Thu Nov  7 2013 gber@opensuse.org
- add manpage dm-tool from trunk
* Thu Nov  7 2013 gber@opensuse.org
- update to version 1.8.5
  - Don't pass system user accounts from AccountsService to
    greeters
  - Fix crash if switching to greeter and it isn't installed
  - Implement missing guest-wrapper functionality and enable it for
    Ubuntu
  - Update AppArmor scripts to work in Ubuntu 13.10
* Thu Oct 31 2013 gber@opensuse.org
- update to version 1.8.3
  - Correctly set  for greeters. This was regressed in 1.7.5 for
    ConsoleKit and was never passed to logind
  - Correctly set user in session setup script
  - Fix notification of sessions being logged out
- drop obsolete lightdm-fix-session-setup-script-env.patch and
  lightdm-set-xdg-session-class.patch
* Tue Oct 22 2013 gber@opensuse.org
- add lightdm-set-xdg-session-class.patch in order to correctly set
  $XDG_SESSION_CLASS for greeters (bnc#846914, lp#1242939,
  backported from upstream bzr)
* Wed Oct 16 2013 gber@opensuse.org
- Update to version 1.8.2
  - Fix crash when starting with existing X servers
* Thu Oct 10 2013 gber@opensuse.org
- update to version 1.8.1
  - Fix crash where Process objects are accessed after unref
* Wed Oct  9 2013 gber@opensuse.org
- update to version 1.8.0
  - Add regression test for corrupt X authority files
* Mon Oct  7 2013 gber@opensuse.org
- update to version 1.7.18
  - Set XDG_VTNR=1 as a fallback if using SeatUnity without a
    functioning compositor or working VT switching, so that logind
    will recognize the VT as active
  - Fix ConsoleKit support broken in 1.7.5
  - Fix --test-mode
  - Add support for running Surfaceflinger sessions
  - surfaceflinger: Set XDG_VTNR=0 if VTs are not available
  - Allow compiling of liblightdm-qt without liblightdm-gobject
  - Add missing documentation for xremote seat options
  - Set session environment variables for guest sessions (1.7
    regression)
  - Don't fail writing X authority if reading it had an error
  - Update environment variables that we pass to Mir
* Wed Sep 11 2013 gber@opensuse.org
- update to version 1.7.14
  - Correctly set permissions on Xauthority file
  - Correctly set $XDG_CURRENT_DESKTOP for non-autologin sessions
  - Fix overallocation of array for strings from greeter
  - Fix truncation writing card32 in XDMCP server
* Sun Sep  8 2013 gber@opensuse.org
- update to version 1.7.12
  - Add xdg-seat config setting
  - Notify Unity System Compositor of the session being
    authenticated
  - Fix crash when greeter quits due to read watch not being
    removed
  - Correctly setup Unity System Compositor environment
  - Improve log messages
  - Fix session locking broken in 1.7.5
  - Load lightdm.conf after lightdm.conf.d/*.conf
  - Also support loading config from /usr/share
  - When switching sessions show a greeter if authentication
    required
  - Set $XDG_CURRENT_DESKTOP if specified in the xsession file
  - Change logging prefixes to make it easier to troubleshoot
    multiseat setups
  - Bring Ubuntu packaging in-tree
  - Correctly set XDG_VTNR for unity sessions that are not
    autologin
  - Add support for Mir sessions and greeters
  - Set XDG_VTNR for unity sessions
  - Fix desktop-session-start upstart signal not being emitted
    since 1.7.5
  - Fix greeter log broken in 1.7.5.
* Tue Jul 23 2013 gber@opensuse.org
- update to version 1.7.7
  - Fix uninitialized pointer introduced in 1.7.3
  - Enable compile warnings and fix code generating warnings
* Mon Jul 22 2013 gber@opensuse.org
- update to version 1.7.6
  - Restore greeter hints that were regressed in 1.7.5.
  - Don't run greeters through session wrapper - regression
    in 1.7.5
  - Quit Plymouth correctly when using the unity seat type
  - Release the VT when the system compositor fails to start
  - Load sessions and greeters from /usr/share/lightdm/sessions and
    /usr/share/lightdm/greeters. The existing directories are
    checked if the sessions are not in these directories.
  - Refactor the Display class so that it merges with the Seat
    class
  - Support running the greeter and session in different display
    servers instead of re-using the same one during a login.
  - Add more regression tests
  - Documentation fixes
  - Set XDG_SEAT and XDG_VTNR environment variables.
  - Add initial support for Unity (i.e. Mir based) seats.
  - Add a greeter wrapper option.
  - Load configuration from /etc/lightdm/lightdm.conf.d.
  - Fix compile warnings
  - Fix tests not running from install directory inside checkout.
  - Fix incorrectly distributed guest-session apparmor data
  - Fix .pc file for liblightdm-qt5-3
  - Add a new option "autologin-in-background" which lets an
    autologin happen in a second display while still showing the
    greeter.
  - Stop if fail to create default seat
  - Add option to set seat type in lightdm-set-defaults
  - Stop using g_file_set_contents - it can leave intermediate
    files around
  - Make tests work without installing them
  - Fix distcheck
- dropped obsolete lightdm-fix-pkgconfig.patch
- added lightdm-fix-session-setup-script-env.patch in order to put
  user information in the environment when running
  session-setup-script
* Sat May  4 2013 hrvoje.senjan@gmail.com
- Added lightdm-fix-pkgconfig.patch, fixes liblightdm-3 pc file
* Thu May  2 2013 gber@opensuse.org
- import pam config used by the gdm greeter which includes
  common-session that in turn contains pam_systemd and registers
  the greeter session allowing suspend/hibernate/reboot/shutdown
- consequently remove lightdm.rules workaround for policykit
* Thu May  2 2013 gber@opensuse.org
- remove support for openSUSE 12.1
- remove dependency on upower
- amend lightdm.rules with a rule for logind
* Wed May  1 2013 tittiatcoke@gmail.com
- Update to version 1.7.0
  - Use logind instead of ConsoleKit if it is available
  - Use Q_SLOTS and Q_SIGNALS instead of slots and signals.
  - Ignore stale X server locks
  - Pass through system locale or set locale from
    AccountsService/.dmrc
  - Fix bug where seat failure before D-Bus acquired would not
    stop daemon
- Dropped patches due to upstream inclusion:
  - lightdm-make-sessions-inherit-system-default-locale.patch
  - lightdm-fix-language-setting.patch
  - lightdm-do-not-strip-codeset-from-language.patch
  - lightdm-fix-function-declarations-missing-prototypes.patch
- Drop Require for ConsoleKit-X11 as that lightdm now supports
  systemd
* Thu Apr 18 2013 gber@opensuse.org
- remove apparmor profile for a guest session which is not
  supported in openSUSE
* Mon Apr 15 2013 gber@opensuse.org
- update to version 1.6.0
  - allow VNC command to be specified in lightdm.conf
  - fix build with gobject-introspection 1.35.9
  - fix authentication cancel regression caused in 1.5.2
  - fix stale X server being left behind when using LockSession
    D-Bus API
  - adjust AppArmor profile to also work with logind
  - don't use GIO to access X authority files - it uses GVFS which
    is unnecessary overhead/complexity
  - handle over/underflows when reading from greeter
  - improve warning message when XDMCP packet has length mismatch
  - only report test command line if it fails
  - add more regression tests
  - QLightDM: Add Qt5 version of the library: liblightdm-qt5-2
  - QLightDM: Add some missing role names in UsersModel
  - QLightDM: Add a backgroundPath role to UsersModel
  - QLightDM: Fix potential crash in QLightDM::UsersModel closedown
  - improve guest session apparmor
  - run each test in its own /tmp dir so they can't interfere with
    eachother
  - fix script hooks no longer working with latest glib
  - fix display clean up code
  - add man page for lightdm-set-defaults
  - use xzip for distribution, don't distribute old metadata
  - correctly check if display is active when session quits
  - relicense liblightdm to LGPL-2/LGPL-3 so GPL-2 code can link
    against it
  - selectively lock memory rather than calling mlockall for main
    daemon
- dropped obsolete lightdm-fix-determining-active-display.patch,
  lightdm-use-fine-grained-memory-locking.patch,
  lightdm-fix-build-with-gobject-introspection-1.35.9.patch
- liblightdm-qt-2-0 and liblightdm-gobject-1-0 were relicensed to
  LGPL-2.0 or LGPL-3.0
* Sun Apr 14 2013 gber@opensuse.org
- added lightdm-fix-function-declarations-missing-prototypes.patch
  in order to fix missing prototypes and pre-ANSI C function
  declarations, this fixes build failures with gnome-common >=
  3.7.4 (lp#1168842)
* Wed Apr  3 2013 gber@opensuse.org
- added lightdm-fix-build-with-gobject-introspection-1.35.9.patch
  in order to fix the build with gobject-introspection >= 1.35.9
  (backported from upstream bzr)
* Wed Mar 27 2013 gber@opensuse.org
- update to version 1.4.1
  - fix script hooks no longer working with latest glib
  - ensure test programs quit when the status socket closes
  - stop deprecation warnings from glib >= 2.36
- updated lightdm-use-fine-grained-memory-locking.patch to
  incoroporate subsequent commit to use mlockall in session-child
  mode
* Thu Feb 21 2013 gber@opensuse.org
- rename lightdm.rules to 50-lightdm.rules to make it easier for
  admins to inject rules in the ordering (bnc#804969)
* Thu Jan 31 2013 gber@opensuse.org
- added lightdm-use-fine-grained-memory-locking.patch in order to
  use libgcrypt to selectively secure password memory instead of
  the big-hammer approach of mlockall (backported from upstrem bzr)
- added lightdm-fix-determining-active-display.patch in order to
  correctly work out the active display from the active VT when it
  exits so a greeter starts (backported from upstrem bzr)
* Wed Jan 30 2013 gber@opensuse.org
- changed lightdm-xauthlocalhostname-support.patch so that
  XAUTHLOCALHOSTNAME is set to the current hostname instead of just
  "localhost" (see
  https://bugzilla.novell.com/show_bug.cgi?id=538064#c25,
  bnc#796230)
- added lightdm-use-run-dir.patch in order to use /run instead of
  /var/run on >= 12.3
* Wed Jan 16 2013 gber@opensuse.org
- add polkit rules which unconditionally allow the lightdm user to
  access to relevant upower/ConsoleKit DBus interfaces for
  suspend/hibernate/reboot/shutdown as access to these methods is
  being denied for unknown reasons since the systemd transition
  (bnc#798769)
* Sun Nov 11 2012 gber@opensuse.org
- remove bogus -o option from useradd
* Mon Nov  5 2012 gber@opensuse.org
- fixed lightdm-fix-language-setting.patch so LANG/GDM_LANG are not
  set if there are no per-user settings
* Sat Nov  3 2012 gber@opensuse.org
- added lightdm-make-sessions-inherit-system-default-locale.patch
  in order to make greeter and user sessions inherit the system
  default locale (lp#1073135, bnc#786926)
- added lightdm-fix-language-setting.patch in order to fix saving/
  retrieving of the language setting (lp#1068853, lp#1019314)
- added lightdm-do-not-strip-codeset-from-language.patch in order
  to prevent stripping the codeset consistent with how the
  Language setting is retrieved from AccountsService (lp#1074946)
* Sat Nov  3 2012 coolo@suse.com
- gdm 3.6.1 brought back gdmflexiserver so remove the conflict again
* Wed Oct 17 2012 gber@opensuse.org
- re-use xdm PAM configuration which is identical and there already
  is a de-facto dependency due to the use of xdm init and session
  scripts
- recommend upower which is needed for hibernate/suspend to work
* Sun Oct  7 2012 gber@opensuse.org
- provide %%{_bindir}/gdmflexiserver for openSUSE > 12.2 since
  gdmflexiserver was dropped from gdm >= 3.6
* Fri Oct  5 2012 gber@opensuse.org
- update to version 1.4.0
  - new major release, please see the included NEWS for a detailed
    list of changes
- added lightdm-disable-utmp-handling.patch which disables utmp
  handling since this is handled in the Xstartup/Xreset scripts
* Thu Apr 19 2012 gber@opensuse.org
- update to version 1.2.2
  - fix wrapper path in AppArmor profile (broken since 1.1.1)
  - add show-manual-login and allow-guest options to
    lightdm-set-defaults
  - add missing regression test script
- dropped lightdm-use-pkglibexecdir.patch which has been
  incorporated upstream
* Fri Apr  6 2012 gber@opensuse.org
- update to version 1.2.0
  - new major release, please see the included NEWS for a detailed
    list of changes
- dropped lightdm-desktop-session-env-pam.patch since
  DESKTOP_SESSION is now in the PAM environment before
  pam_open_session() is called
- dropped lightdm-remove-xauthority-ownership-fix.patch since the
  code has been removed by upstream
- dropped lightdm-call-g_thread_init-conditionally.patch since the
  problem has been fixed by upstream
- removed lightdm-gtk-greeter and lightdm-qt-greeter which are now
  separate projects
* Wed Mar 21 2012 gber@opensuse.org
- update to version 1.0.10
  - fix compilation failure in liblightdm-qt with GCC 4.7
- dropped obsolete lightdm-fix-missing-includes.patch
* Sat Mar 17 2012 boris@steki.net
- add lightdm-fix-missing-includes.patch which adds missing
  includes (lp#958097)
* Fri Mar  2 2012 gber@opensuse.org
- update to version 1.0.9
  - stop file descriptors leaking into the session processes
    (bnc#745339, lp#927060, CVE-2012-1111)
  - fix compilation against gthread
  - change session directory once user permissions are set so it
    works on NFS filesystems that don't allow root to access files
  - fix object cleanup on exit
  - fix lightdm --debug not working on newer GLib
  - drop privileges when reading ~/.dmrc (CVE-2011-3153)
  - fix crash calling lightdm_get_layout
- drop lightdm-CVE-2011-3153.patch which has been included upstream
* Sun Jan  8 2012 gber@opensuse.org
- added lightdm-call-g_thread_init-conditionally.patch in order to
  call g_thread_init() only on glib < 2.31.0
- no need to own %%{_libexecdir}/X11/
* Sat Dec  3 2011 gber@opensuse.org
- regenerate moc files
* Tue Nov 15 2011 prusnak@opensuse.org
- fix .dmrc handling (CVE-2011-3153) [bnc#728627]
* Thu Nov 10 2011 gber@opensuse.org
- added lightdm-remove-xauthority-ownership-fix.patch which removes
  the code correcting the ownership of .Xauthority files, it is
  still not secure and the buggy LightDM version writing
  .Xauthority as root never was in a released openSUSE version
  anyway (bnc#730062)
* Wed Nov  2 2011 gber@opensuse.org
- Update to version 1.0.6
  - use lchown for correcting ownership of ~/.Xauthority instead of
    chown, this fixes a security issue where using ~/.Xauthority as
    a symlink would cause LightDM to set the destination of the
    link to user ownership (CVE-2011-4105)
* Sun Oct 30 2011 gber@opensuse.org
- added dependency on gnome-themes-accessibility to
  lightdm-gtk-greeter in order to make it high contrast
  accessibility option work
* Thu Oct 27 2011 gber@opensuse.org
- update to version 1.0.5
  - relax AppArmor guest profile to allow compiz to start
  - connect up VNC settings for width, height, depth
- dropped lightdm-vnc-configuration.patch which has been integrated
* Wed Oct 26 2011 gber@opensuse.org
- update to version 1.0.4
  - fix --enable-gtk-greeter=yes not working
  - fix X sessions with arguments in Exec not working
  - use previous session for automatic login or if greeter does not
    request one
  - correct ownership of ~/.Xauthority if upgrading from buggy
    version of LightDM that had it root owned
  - set default resolution of VNC to 1024x768, add settings for
    width, height, depth into lightdm.conf
  - AppArmor profile: Fix broken gnome-keyring and dbus/gwibber,
    and quiesce annoying kernel audit messages for privileges that
    we definitively do not want to grant
  - set LOGNAME environment variable
* Tue Oct 18 2011 gber@opensuse.org
- added lighdm-vnc-configuration.patch in order to set the default
  resolution of VNC to 1024x768, add settings for width, height,
  depth into lightdm.conf
* Sat Oct  8 2011 gber@opensuse.org
- update to version 1.0.3
  - fix reference counting issue in ConsoleKit code
  - really add the lightdm-guest-session-wrapper
- added lightdm-use-pkglibexecdir.patch in order to use
  pkglibexecdir instead of libexecdir for helper binaries/scripts
* Thu Oct  6 2011 gber@opensuse.org
- update to version 1.0.2
  - fix daemon from blocking if Accounts Service does not exist
  - fix greeter log file not being written
  - don't set LANG environment variable if using Accounts Service
  - fix gdmflexiserver not working due to it not being in PATH
  - don't authenticate the greeter user
  - allow greeters to be disabled in configure flags
  - fix over allocation of read buffer in greeter protocol
  - make sure objects are cleaned up on exit
  - fix minor memory leaks
  - fix hugely oversized allocation in greeter buffer, can trigger
    crashes when entering very long passwords
* Wed Oct  5 2011 gber@opensuse.org
- update to version 1.0.1
  - GTK greeter now remembers last user
  - GTK greeter now initializes i18n
  - start authentication for automatically selected user in GTK
    greeter
  - link liblightdm-qt against QtGui
  - fix liblightdm-qt crashing when face images are installed
  - set correct permissions on session log files
  - prefer a locale with a codeset over one without for setting
    LANG
  - introduce a lightdm-guest-session-wrapper session command
    which MAC systems like AppArmor and SELinux can use for
    attaching a restrictive policy to guest sessions
  - provide an AppArmor profile for guest session lockdown
* Mon Oct  3 2011 gber@opensuse.org
- add dependency on ConsoleKit-x11
- add optional dependency on accountsservice to
  liblightdm-gobject-1-0
* Wed Sep 28 2011 gber@opensuse.org
- update to version 1.0.0
  - explicitly grab keyboard focus in GTK greeter
  - fix removed power and a11y menu items in GTK greeter
  - put system binary directory into path when running in test mode
  - call pam_getenvlist after pam_setcred
* Mon Sep 26 2011 gber@opensuse.org
- make greeters depend on main package
* Thu Sep 22 2011 gber@opensuse.org
- update to version 0.9.8
  - allow lightdm --version to be run as non-root
  - automatically respond to PAM messages without prompts
  - create 'AddLocalXSeat' D-Bus method, and require root to use
    'AddSeat'
  - fix multi-seat configuration picking the same display number
  - use correct D-Bus and power interface in liblightdm-qt
  - run pam_setcred inside the session process so pam_group works
  - make sure one session is always selected in the GTK greeter
- install displaymanager configuration script into
  %%{_libexecdir}/X11/displaymanagers/ (bnc#714003)
* Tue Sep 20 2011 gber@opensuse.org
- update to current pre-0.9.8 bzr snapshot
  - add ability to set the language of a user from the greeter
  - set LANG variable based on the user language
  - add language selector into GTK greeter (disabled by default)
  - allow TCP/IP connections if xserver-allow-tcp is true
* Mon Sep 19 2011 gber@opensuse.org
- added configuration script for /etc/init.d/xdm
* Mon Sep 19 2011 gber@opensuse.org
- update to current pre-0.9.8 bzr snapshot
  - Remove GetSeatForCookie and GetSessionForCookie now
    XDG_SEAT_PATH and XDG_SESSION_PATH exist
  - Change log filenames to be unique across different display
    types
  - Fix up script hooks, add regression tests for them
  - Complete removal of X code from the core of LightDM, so it can
    better support various display types
  - Set PAM_TTY to the display name, not the tty device
  - Only unlock displays if switched to from greeter
  - Make log file not system readable
  - Write ~/.Xauthority inside the session process so it cannot be
    hijacked
  - Set PAM_TTY and PAM_XDISPLAY when opening PAM session
  - Add VNC server support
  - Do not write ~/.dmrc and ~/.Xauthority as root, this addresses
    CVE-2011-3349
* Wed Sep  7 2011 gber@opensuse.org
- update to version 0.9.5
  - use accounts service in the daemon if it is available
  - correctly load seat type in multi seat configuration
  - add display-setup, session-setup and session-cleanup scripting
    hooks
  - fix cancel button in GTK greeter
  - fix line through GTK greeter menu items
  - exit daemon if a seat fails which has exit-on-failure set to
    true
  - add HasGuestAccount property to seat D-Bus interface
  - fix XDMCP authorization
  - update man file
- removed lightdm-fix-underlinking.patch and
  lightdm-add-scripting-hooks.patch which have been integrated
  upstream
- depend on the new gdmflexiserver compatibility wrapper
* Sat Sep  3 2011 gber@opensuse.org
- add branding for lightdm-gtk-greeter
* Fri Sep  2 2011 gber@opensuse.org
- reworked lightdm-add-scripting-hooks.patch in order to match the
  version committed upstream
- added lightdm-set-gdmflexiserver-envvar.patch which sets the
  GDMFLEXISERVER environment variable for the gdmflexiserver
  wrapper
- added lightdm-lock-screen-before-switch.patch in order to try
  locking the screen before switching users
- fixed usage of --libexecdir
* Sat Aug 27 2011 gber@opensuse.org
- use update-alternatives for selecting the default greeter
* Sat Aug 27 2011 gber@opensuse.org
- added lightdm-fix-underlinking.patch in order to fix an
  underlinking issue with test-qt-greeter
* Thu Aug 25 2011 andrea@opensuse.org
- Added proper Supplements for the greeters
- remove version require for the greeters, 3rd party greeters
  don't always follow the same version as lightdm
* Tue Aug 23 2011 gber@opensuse.org
- added lightdm-add-scripting-hooks.patch which implements
  scripting hooks compatible with xdm/gdm (lp#602505)
* Mon Aug 22 2011 gber@opensuse.org
- update to verion 0.9.4
  - lightdm-set-defaults enables tweaking the default session and
    chosen greeter for lightdm
  - move xsessions-directory and xgreeters-directory from
    [SeatDefaults] to [LightDM].
  - add AddSeat D-Bus method for adding dynamic seats
  - added a dm-tool program that allows user switching and adding
    seats
  - allow remote X servers, e.g. launched using dm-tool
    add-nested-seat
  - don't allow autologin-username to be set to empty
- removed obsolete lightdm-handle-empty-autologin-user.patch
- package gdmflexiserver under libexecdir
* Mon Aug 22 2011 andrea@opensuse.org
- added dbus-glib-1 as build requires to fix pkgconfig dependencies
* Mon Aug 22 2011 gber@opensuse.org
- fixed typo
- removed dependency of lightdm-gobject-devel on lightdm
- removed stale dependency of lightdm-gtk-greeter on gtk2
* Thu Aug 11 2011 gber@opensuse.org
- update to version 0.9.3
  - unlock ConsoleKit sessions when switching to them
  - add a gdmflexiserver binary that provides backwards
    compatibility with existing sessions
  - set XDG_SEAT_PATH and XDG_SESSION_PATH environment variables
    for sessions
  - always set XAUTHORITY environment variable so sudo keeps
    accessing the correct X authority
  - connect up lightdm_user_get_logged_in in liblightdm-gobject
  - ignore sessions that fail TryExec or are hidden
  - add missing home_directory User property missing in Vala
    bindings
* Sun Jul 31 2011 gber@opensuse.org
- changed lightdm-sysconfig-support.patch so that the sysconfig
  parser does not print debug information which would go to the
  console
* Thu Jul 28 2011 gber@opensuse.org
- fixed some typos in lightdm-sysconfig-support.patch and
  lightdm-handle-empty-autologin-user.patch and handle invalid
  autologin-user properly
* Tue Jul 26 2011 gber@opensuse.org
- update to version 0.9.2:
  - fix annotation and Vala bindings for getting the UserList
    singleton
  - fix GTK+ greeter error label not being shown
  - don't set SIGQUIT to ignore in child processes
  - reworked the PAM code as ecryptfs users weren't able to log in
- added lightdm-handle-empty-autologin-user.patch in order to
  prevent auto-login as nobody when autologin-user or
  DISPLAYMANAGER_AUTOLOGIN are set to an empty string
- added patch tags
- split off -lang subpackage
* Mon Jul 25 2011 gber@opensuse.org
- initial packaging
